pub(crate) fn register_pmcs_for_all_users() -> boolExpand description
This function is called by functions generated by the pmc_entry_points
macro to check if the unit operation is registered for all users.
Registering a PMC for all users requires administrative privileges.
Returns
false